@@ -34,35 +34,48 @@ const Widget = GObject.registerClass({
         this._changedPermitted = false;
 
         this._store = new Gtk.ListStore();
-        this._store.set_column_types([Gio.AppInfo, GObject.TYPE_STRING, Gio.Icon, GObject.TYPE_INT,
-                                      Gtk.Adjustment]);
+        this._store.set_column_types([
+            Gio.AppInfo,
+            GObject.TYPE_STRING,
+            Gio.Icon,
+            GObject.TYPE_INT,
+            Gtk.Adjustment
+        ]);
 
         let scrolled = new Gtk.ScrolledWindow({ shadow_type: Gtk.ShadowType.IN });
         scrolled.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
         this.add(scrolled);
 
 
-        this._treeView = new Gtk.TreeView({ model: this._store,
-                                            hexpand: true, vexpand: true });
+        this._treeView = new Gtk.TreeView({
+            model: this._store,
+            hexpand: true,
+            vexpand: true
+        });
         this._treeView.get_selection().set_mode(Gtk.SelectionMode.SINGLE);
 
-        let appColumn = new Gtk.TreeViewColumn({ expand: true, sort_column_id: Columns.DISPLAY_NAME,
-                                                 title: _("Application") });
+        let appColumn = new Gtk.TreeViewColumn({
+            expand: true,
+            sort_column_id: Columns.DISPLAY_NAME,
+            title: _('Application')
+        });
         let iconRenderer = new Gtk.CellRendererPixbuf;
         appColumn.pack_start(iconRenderer, false);
-        appColumn.add_attribute(iconRenderer, "gicon", Columns.ICON);
+        appColumn.add_attribute(iconRenderer, 'gicon', Columns.ICON);
         let nameRenderer = new Gtk.CellRendererText;
         appColumn.pack_start(nameRenderer, true);
-        appColumn.add_attribute(nameRenderer, "text", Columns.DISPLAY_NAME);
+        appColumn.add_attribute(nameRenderer, 'text', Columns.DISPLAY_NAME);
         this._treeView.append_column(appColumn);
 
-        let workspaceColumn = new Gtk.TreeViewColumn({ title: _("Workspace"),
-                                                       sort_column_id: Columns.WORKSPACE });
+        let workspaceColumn = new Gtk.TreeViewColumn({
+            title: _('Workspace'),
+            sort_column_id: Columns.WORKSPACE
+        });
         let workspaceRenderer = new Gtk.CellRendererSpin({ editable: true });
         workspaceRenderer.connect('edited', this._workspaceEdited.bind(this));
         workspaceColumn.pack_start(workspaceRenderer, true);
-        workspaceColumn.add_attribute(workspaceRenderer, "adjustment", Columns.ADJUSTMENT);
-        workspaceColumn.add_attribute(workspaceRenderer, "text", Columns.WORKSPACE);
+        workspaceColumn.add_attribute(workspaceRenderer, 'adjustment', Columns.ADJUSTMENT);
+        workspaceColumn.add_attribute(workspaceRenderer, 'text', Columns.WORKSPACE);
         this._treeView.append_column(workspaceColumn);
 
         scrolled.add(this._treeView);
@@ -71,13 +84,15 @@ const Widget = GObject.registerClass({
         toolbar.get_style_context().add_class(Gtk.STYLE_CLASS_INLINE_TOOLBAR);
         this.add(toolbar);
 
-        let newButton = new Gtk.ToolButton({ icon_name: 'bookmark-new-symbolic',
-                                             label: _("Add Rule"),
-                                             is_important: true });
+        let newButton = new Gtk.ToolButton({
+            icon_name: 'bookmark-new-symbolic',
+            label: _('Add Rule'),
+            is_important: true
+        });
         newButton.connect('clicked', this._createNew.bind(this));
         toolbar.add(newButton);
 
-        let delButton = new Gtk.ToolButton({ icon_name: 'edit-delete-symbolic'  });
+        let delButton = new Gtk.ToolButton({ icon_name: 'edit-delete-symbolic' });
         delButton.connect('clicked', this._deleteSelected.bind(this));
         toolbar.add(delButton);
 
@@ -92,17 +107,21 @@ const Widget = GObject.registerClass({
     }
 
     _createNew() {
-        let dialog = new Gtk.Dialog({ title: _("Create new matching rule"),
-                                      transient_for: this.get_toplevel(),
-                                      use_header_bar: true,
-                                      modal: true });
+        let dialog = new Gtk.Dialog({
+            title: _('Create new matching rule'),
+            transient_for: this.get_toplevel(),
+            use_header_bar: true,
+            modal: true
+        });
         dialog.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL);
-        let addButton = dialog.add_button(_("Add"), Gtk.ResponseType.OK);
+        let addButton = dialog.add_button(_('Add'), Gtk.ResponseType.OK);
         dialog.set_default_response(Gtk.ResponseType.OK);
 
-        let grid = new Gtk.Grid({ column_spacing: 10,
-                                  row_spacing: 15,
-                                  margin: 10 });
+        let grid = new Gtk.Grid({
+            column_spacing: 10,
+            row_spacing: 15,
+            margin: 10
+        });
         dialog._appChooser = new Gtk.AppChooserWidget({ show_all: true });
         dialog._appChooser.connect('application-selected', (w, appInfo) => {
             addButton.sensitive = appInfo && this._checkId(appInfo.get_id());
@@ -111,13 +130,19 @@ const Widget = GObject.registerClass({
         addButton.sensitive = appInfo && this._checkId(appInfo.get_id());
 
         grid.attach(dialog._appChooser, 0, 0, 2, 1);
-        grid.attach(new Gtk.Label({ label: _("Workspace"),
-                                    halign: Gtk.Align.END }), 0, 1, 1, 1);
-        let adjustment = new Gtk.Adjustment({ lower: 1,
-                                              upper: WORKSPACE_MAX,
-                                              step_increment: 1 });
-        dialog._spin = new Gtk.SpinButton({ adjustment: adjustment,
-                                            snap_to_ticks: true });
+        grid.attach(new Gtk.Label({
+            label: _('Workspace'),
+            halign: Gtk.Align.END
+        }), 0, 1, 1, 1);
+        let adjustment = new Gtk.Adjustment({
+            lower: 1,
+            upper: WORKSPACE_MAX,
+            step_increment: 1
+        });
+        dialog._spin = new Gtk.SpinButton({
+            adjustment: adjustment,
+            snap_to_ticks: true
+        });
         dialog._spin.set_value(1);
         grid.attach(dialog._spin, 1, 1, 1, 1);
         dialog.get_content_area().add(grid);
@@ -139,14 +164,7 @@ const Widget = GObject.registerClass({
             this._appendItem(appInfo.get_id(), index);
             this._changedPermitted = true;
 
-            let iter = this._store.append();
-            let adj = new Gtk.Adjustment({ lower: 1,
-                                           upper: WORKSPACE_MAX,
-                                           step_increment: 1,
-                                           value: index });
-            this._store.set(iter,
-                            [Columns.APPINFO, Columns.ICON, Columns.DISPLAY_NAME, Columns.WORKSPACE, Columns.ADJUSTMENT],
-                            [appInfo, appInfo.get_icon(), appInfo.get_display_name(), index, adj]);
+            this._appendRow(appInfo, index);
 
             dialog.destroy();
         });
@@ -196,20 +214,29 @@ const Widget = GObject.registerClass({
                 continue;
             validItems.push(currentItems[i]);
 
-            let iter = this._store.append();
-            let adj = new Gtk.Adjustment({ lower: 1,
-                                           upper: WORKSPACE_MAX,
-                                           step_increment: 1,
-                                           value: index });
-            this._store.set(iter,
-                            [Columns.APPINFO, Columns.ICON, Columns.DISPLAY_NAME, Columns.WORKSPACE, Columns.ADJUSTMENT],
-                            [appInfo, appInfo.get_icon(), appInfo.get_display_name(), parseInt(index), adj]);
+            this._appendRow(appInfo, parseInt(index));
         }
 
         if (validItems.length != currentItems.length) // some items were filtered out
             this._settings.set_strv(SETTINGS_KEY, validItems);
     }
 
+    _appendRow(appInfo, workspace) {
+        let iter = this._store.append();
+        let icon = appInfo.get_icon();
+        let displayName = appInfo.get_display_name();
+        let adj = new Gtk.Adjustment({
+            lower: 1,
+            upper: WORKSPACE_MAX,
+            step_increment: 1,
+            value: workspace
+        });
+        let { APPINFO, ICON, DISPLAY_NAME, WORKSPACE, ADJUSTMENT } = Columns;
+        this._store.set(iter,
+            [APPINFO, ICON, DISPLAY_NAME, WORKSPACE, ADJUSTMENT],
+            [appInfo, icon, displayName, workspace, adj]);
+    }
+
     _checkId(id) {
         let items = this._settings.get_strv(SETTINGS_KEY);
         return !items.some(i => i.startsWith(`${id}:`));
