@@ -5,13 +5,12 @@ const { Gio, GObject, Shell, St } = imports.gi;
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
 
+const ExtensionUtils = imports.misc.extensionUtils;
 const Main = imports.ui.main;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
 const ShellMountOperation = imports.ui.shellMountOperation;
 
-const ExtensionUtils = imports.misc.extensionUtils;
-
 var MountMenuItem = GObject.registerClass(
 class MountMenuItem extends PopupMenu.PopupBaseMenuItem {
     _init(mount) {
@@ -153,7 +152,7 @@ class DriveMenu extends PanelMenu.Button {
     }
 
     _updateMenuVisibility() {
-        if (this._mounts.filter(i => i.actor.visible).length > 0)
+        if (this._mounts.filter(i => i.visible).length > 0)
             this.show();
         else
             this.hide();
