@@ -22,16 +22,20 @@ class WindowListPrefsWidget extends Gtk.Grid {
         this.row_spacing = 6;
         this.orientation = Gtk.Orientation.VERTICAL;
 
-        let groupingLabel = '<b>%s</b>'.format(_("Window Grouping"));
-        this.add(new Gtk.Label({ label: groupingLabel, use_markup: true,
-                                 halign: Gtk.Align.START }));
+        let groupingLabel = '<b>%s</b>'.format(_('Window Grouping'));
+        this.add(new Gtk.Label({
+            label: groupingLabel, use_markup: true,
+            halign: Gtk.Align.START
+        }));
 
         let align = new Gtk.Alignment({ left_padding: 12 });
         this.add(align);
 
-        let grid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
-                                  row_spacing: 6,
-                                  column_spacing: 6 });
+        let grid = new Gtk.Grid({
+            orientation: Gtk.Orientation.VERTICAL,
+            row_spacing: 6,
+            column_spacing: 6
+        });
         align.add(grid);
 
         this._settings = ExtensionUtils.getSettings();
@@ -40,9 +44,9 @@ class WindowListPrefsWidget extends Gtk.Grid {
         let modes = range.deep_unpack()[1].deep_unpack();
 
         let modeLabels = {
-            'never': _("Never group windows"),
-            'auto': _("Group windows when space is limited"),
-            'always': _("Always group windows")
+            'never': _('Never group windows'),
+            'auto': _('Group windows when space is limited'),
+            'always': _('Always group windows')
         };
 
         let radio = null;
@@ -54,9 +58,11 @@ class WindowListPrefsWidget extends Gtk.Grid {
                 continue;
             }
 
-            radio = new Gtk.RadioButton({ active: currentMode == mode,
-                                          label: label,
-                                          group: radio });
+            radio = new Gtk.RadioButton({
+                active: currentMode == mode,
+                label: label,
+                group: radio
+            });
             grid.add(radio);
 
             radio.connect('toggled', button => {
@@ -65,10 +71,19 @@ class WindowListPrefsWidget extends Gtk.Grid {
             });
         }
 
-        let check = new Gtk.CheckButton({ label: _("Show on all monitors"),
-                                          margin_top: 6 });
+        let check = new Gtk.CheckButton({
+            label: _('Show on all monitors'),
+            margin_top: 6
+        });
         this._settings.bind('show-on-all-monitors', check, 'active', Gio.SettingsBindFlags.DEFAULT);
         this.add(check);
+
+        check = new Gtk.CheckButton({
+            label: _('Show windows from all workspaces'),
+            margin_top: 6
+        });
+        this._settings.bind('display-all-workspaces', check, 'active', Gio.SettingsBindFlags.DEFAULT);
+        this.add(check);
     }
 });
 
